package Mnet::Opts::Set::Silent;

=head1 NAME

Mnet::Opts::Set::Silent - Use this module to enable --silent option

=head1 SYNOPSIS

    use Mnet::Opts::Set::Silent;

=head1 DESCROPTION

Use this module to enable the --silent option for the Mnet::Log module.

Refer to the Mnet::Log module for more information.

=cut

# required modules
use warnings;
use strict;

=head1 SEE ALSO

L<Mnet>

L<Mnet::Log>

=cut

# normal end of package
1;

